@@ -4,6 +4,8 @@ Generic django admin extensions.
 
 from django.contrib import admin
 
+__all__ = ('DragAndDropAdmin', 'abstract', 'fields', 'forms', 'models', 'utils')
+
 class DragAndDropAdmin(admin.ModelAdmin):
     """
     Admin class that allows dragging and dropping of items
@@ -15,9 +17,9 @@ class DragAndDropAdmin(admin.ModelAdmin):
     
     class Media:
         js = (
-            'cms/js/lib/jquery.js',
-            'cms/js/lib/ui.core.js',
-            'cms/js/lib/ui.sortable.js',
+            'js/lib/jquery.js',
+            'js/lib/ui.core.js',
+            'js/lib/ui.sortable.js',
             'easymode/js/menu-sort.js',            
         )
         
