@@ -1,12 +1,12 @@
-from functools import wraps
 import os.path
 import shutil
+from functools import wraps
 
-from django.contrib.auth.models import User
 from django.conf import settings
-from easymode.tests.models import *
+
 from easymode.tests.testutils import TestSettingsManager
 
+
 def initdb(cls):
     """
     This is a class decorator.
@@ -18,34 +18,29 @@ def initdb(cls):
     Then at the end they are removed again.
     """
     
-    orig_setup = cls.setUp
-    orig_teardown = cls.tearDown
+    orig_pre_setup = getattr(cls, '_pre_setup')
+    orig_post_teardown = getattr(cls, '_post_teardown')
     
-    @wraps(orig_setup)
-    def setUp(self):
+    @wraps(orig_pre_setup)
+    def _pre_setup(self):
         self.settingsManager = TestSettingsManager()
         self.settingsManager.set(INSTALLED_APPS=settings.INSTALLED_APPS+[
             'easymode',
             'easymode.tests',
             ],
         )
-        
-        u = User(username="admin")
-        u.set_password("admin")
-        u.is_staff = True
-        u.is_active = True
-        u.is_superuser = True 
-        u.save()
-        
+                
         for skipped_test in getattr(settings , 'SKIPPED_TESTS', []):
             if hasattr(cls, skipped_test):
                 setattr(cls, skipped_test, lambda x: True)
-
-        orig_setup(self)
+        
+        if orig_pre_setup:
+            orig_pre_setup(self)
     
-    @wraps(orig_teardown)
-    def tearDown(self):
-        orig_teardown(self)
+    @wraps(orig_post_teardown)
+    def _post_teardown(self):
+        if orig_post_teardown:
+            orig_post_teardown(self)
         # don't try to remove the locale dir in the project dir because it has all translations
         # test cases should have a separate locale dir, preferably in /tmp
         if not (os.path.normpath(settings.LOCALE_DIR) == os.path.normpath(settings.PROJECT_DIR)):
@@ -54,6 +49,6 @@ def initdb(cls):
                 shutil.rmtree(locale_dir)
         self.settingsManager.revert()
         
-    cls.setUp = setUp
-    cls.tearDown = tearDown
+    cls._pre_setup = _pre_setup
+    cls._post_teardown = _post_teardown
     return cls
