@@ -4,8 +4,7 @@ from django.utils.text import capfirst
 __all__ = ('standin_for',)
 
 _defined_standins = dict()
-
-
+    
 def standin_for(obj, **attrs):
     """
     Returns an object that can be used as a standin for the original object.
@@ -28,6 +27,15 @@ def standin_for(obj, **attrs):
     True
     >>> type(b)
     <class 'easymode.utils.standin.unicodeOriginAndPackageStandIn'>
+    >>> import pickle
+    >>> b_pickle = pickle.dumps(b, pickle.HIGHEST_PROTOCOL)
+    >>> c = pickle.loads(b_pickle)
+    >>> b == c
+    True
+    >>> c.origin
+    'outerspace'
+    >>> c.package
+    'easymode.utils.standin'
     
     Some types are not supported by standin_for. This is because these types are often used in statements like::
         
@@ -70,6 +78,13 @@ def standin_for(obj, **attrs):
     attr_names  = attrs.keys()
     attr_names.sort()
 
+    # Contruct __reduce__ method, so the resulting class can be pickled
+    attrs_org = attrs.copy() # Create a copy to be used forx the recude method
+    def __reduce__(self, ignore=None):
+        return (dict_standin_for, (obj, attrs_org))
+    attrs['__reduce__'] = __reduce__
+    attrs['__reduce_ex__']= __reduce__
+
     # create a readable class name eg. unicodeAndTitleAndDescription
     additions = 'And'.join(map(capfirst, attr_names))
     id = "%s%s" % (obj_class.__name__, additions.encode('ascii', 'ignore'))
@@ -90,7 +105,7 @@ def standin_for(obj, **attrs):
             stand_in.__dict__.update(obj.__dict__)
         except (AttributeError, TypeError):
             stand_in = obj
-    
+
     # add extra attrs
     try:
         for (key, value) in attrs.iteritems():
@@ -99,4 +114,7 @@ def standin_for(obj, **attrs):
         # if nothing works return original object
         return obj
     
-    return stand_in
\ No newline at end of file
+    return stand_in
+    
+def dict_standin_for(obj, attrs):
+    return standin_for(obj, **attrs)
\ No newline at end of file
