@@ -1,4 +1,4 @@
 from settings import *
 
 INSTALLED_APPS += ('django_nose', )
-TEST_RUNNER = 'django_nose.run_tests'
\ No newline at end of file
+TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
\ No newline at end of file
